;; Generated package description from markdown-mode.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "markdown-mode" "2.9alpha0.20260722.13" "Major mode for Markdown-formatted text" '((emacs "28.1")) :commit "f441e8bc9951e73b12c61e9198658488dd8e86e1" :authors '(("Jason R. Blevins" . "jblevins@xbeta.org")) :maintainer '("Jason R. Blevins" . "jblevins@xbeta.org") :keywords '("markdown" "github flavored markdown" "itex") :url "https://jblevins.org/projects/markdown-mode/")
